/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsMapping.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.xmlconfig.mapping;

import java.util.ArrayList;
import java.util.List;

/**
 * Common methods used by mapping class.
 * @author Florent Benoit
 */
public abstract class AbsMapping {

    /**
     * List of aliases for this mapping.
     */
    private List<String> aliases;

    /**
     * Name of the mapping element.
     */
    private String name = null;

    /**
     * Default constructor.
     */
    public AbsMapping() {
        this.aliases = new ArrayList<String>();
    }

    /**
     * Gets name of this mapping element.
     * @return the name.
     */
    public String getName() {
        return this.name;
    }

    /**
     * Sets the name for this mapping.
     * @param name the given name.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Sets the aliases for this mapping.
     * @param aliases the given aliases.
     */
    public void setAliases(final List<String> aliases) {
        this.aliases = aliases;
    }

    /**
     * Gets aliases used.
     * @return the aliases of this mapping class.
     */
    public List<String> getAliases() {
        return aliases;
    }

    /**
     * Returns a string representation of the object.
     * @return string representation
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("name=");
        sb.append(name);
        sb.append(", aliases=");
        sb.append(aliases);
        return sb.toString();
    }
}
